##  Mapping Processes to Fact Sheet Subtypes
Through field mapping settings, processes can be mapped to business context fact sheet subtypes. To map processes to fact sheet subtypes, follow these steps:
  1. In the field mapping modal, choose Static Text for the mapping type.
  2. Select Subtype from the SAP LeanIX field drop-down list
  3. Select the needed process type from the SAP Signavio drop-down list.


![Mapping Processes to Fact Sheet Subtypes](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2753435d7a441014ac24e8e9bab72fd9_LowRes.png)
Mapping Processes to Fact Sheet Subtypes
